@@ -23,9 +23,10 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <gnome.h>
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
 #include <libgnomeprint/gnome-print.h>
-#include <libgnomeprint/gnome-print-preview.h>
+#include <libgnomeprintui/gnome-print-preview.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <gal/e-table/e-tree-memory-callbacks.h>
@@ -246,14 +247,20 @@ collapse_all (GtkButton *button, gpointer data)
 static void
 print_tree (GtkButton *button, gpointer data)
 {
+#ifndef NO_WARNINGS
+#warning Need to fix printing ...
+#endif
+#if 0
 	EPrintable *printable = e_tree_get_printable (E_TREE (e_tree));
 	GnomePrintContext *gpc;
 
-	gpc = gnome_print_context_new (gnome_printer_new_generic_ps ("tree-out.ps"));
+	gpc = gnome_print_context_new (
+		gnome_printer_new_generic_ps ("tree-out.ps"));
 
 	e_printable_print_page (printable, gpc, 8*72, 10*72, FALSE);
 
 	gnome_print_context_close (gpc);
+#endif
 }
 
 static void
@@ -350,35 +357,35 @@ create_tree (void)
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
 
 	button = gtk_button_new_with_label ("Toggle Root Node");
-	gtk_signal_connect (GTK_OBJECT (button), "clicked", toggle_root, e_tree_model);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked", GTK_SIGNAL_FUNC(toggle_root), e_tree_model);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
 	button = gtk_button_new_with_label ("Add Sibling");
-	gtk_signal_connect (GTK_OBJECT (button), "clicked", add_sibling, e_tree_model);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked", GTK_SIGNAL_FUNC(add_sibling), e_tree_model);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
 	button = gtk_button_new_with_label ("Add Child");
-	gtk_signal_connect (GTK_OBJECT (button), "clicked", add_child, e_tree_model);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked", GTK_SIGNAL_FUNC(add_child), e_tree_model);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
 	button = gtk_button_new_with_label ("Remove Node");
-	gtk_signal_connect (GTK_OBJECT (button), "clicked", remove_node, e_tree_model);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked", GTK_SIGNAL_FUNC(remove_node), e_tree_model);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
 	button = gtk_button_new_with_label ("Expand All Below");
-	gtk_signal_connect (GTK_OBJECT (button), "clicked", expand_all, e_tree_model);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked", GTK_SIGNAL_FUNC(expand_all), e_tree_model);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
 	button = gtk_button_new_with_label ("Collapse All Below");
-	gtk_signal_connect (GTK_OBJECT (button), "clicked", collapse_all, e_tree_model);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked", GTK_SIGNAL_FUNC(collapse_all), e_tree_model);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
 	button = gtk_button_new_with_label ("Print Tree");
-	gtk_signal_connect (GTK_OBJECT (button), "clicked", print_tree, e_tree_model);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked", GTK_SIGNAL_FUNC(print_tree), e_tree_model);
 	gtk_box_pack_end (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
 	button = gtk_button_new_with_label ("Save State");
-	gtk_signal_connect (GTK_OBJECT (button), "clicked", save_state, e_tree_model);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked", GTK_SIGNAL_FUNC(save_state), e_tree_model);
 	gtk_box_pack_end (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
 	gtk_container_add (GTK_CONTAINER (window), vbox);
@@ -398,7 +405,6 @@ main (int argc, char *argv [])
 {
 	gnome_init ("TreeExample", "TreeExample", argc, argv);
 
-	gtk_widget_push_visual (gdk_rgb_get_visual ());
 	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	create_tree ();
